@@ -22,7 +22,7 @@ use FusionInventory::Agent::Tools;
 use FusionInventory::Agent::Tools::Hostname;
 use FusionInventory::Agent::XML::Query::Prolog;
 
-our $VERSION = '2.2.2';
+our $VERSION = '2.2.4';
 our $VERSION_STRING = 
     "FusionInventory unified agent for UNIX, Linux and MacOSX ($VERSION)";
 our $AGENT_STRING =
@@ -143,8 +143,17 @@ sub init {
             $logger->error("Can't load Proc::Daemon. Is the module installed?");
             exit 1;
         }
+
+        my $cwd = getcwd();
         Proc::Daemon::Init();
         $logger->debug("Daemon started");
+
+
+        # If we use relative path, we must stay in the current directory
+        if (substr( $params{libdir}, 0, 1 ) ne '/') {
+            chdir($cwd);
+        }
+
         if ($self->_isAlreadyRunning()) {
             $logger->debug("An agent is already runnnig, exiting...");
             exit 1;
@@ -218,6 +227,7 @@ sub _runTarget {
     if ($target->isa('FusionInventory::Agent::Target::Server')) {
         my $client = FusionInventory::Agent::HTTP::Client::OCS->new(
             logger       => $self->{logger},
+            timeout      => $self->{timeout},
             user         => $self->{config}->{user},
             password     => $self->{config}->{password},
             proxy        => $self->{config}->{proxy},
@@ -519,6 +529,6 @@ Get all available tasks found on the system, as a list of module / version
 pairs:
 
 %tasks = (
-    'FusionInventory::Agent::Task::Foo' => x,
-    'FusionInventory::Agent::Task::Bar' => y,
+    'Foo' => x,
+    'Bar' => y,
 );
